@@ -1,6 +1,7 @@
 import importlib
 from decimal import Decimal
 
+from sqlalchemy.orm import declarative_base
 from tornado.options import options
 
 sqlalchemy_orm = None
@@ -66,15 +67,48 @@ def sqlalchemy_paging(Query, limit_number, offset_number):
     return {"count": data_count, "dataSource": data_list}
 
 
+def covert_relationship_property(attr, attr_value):
+    if attr.__class__.__name__ == 'ColumnProperty':
+        return attr_value
+    elif attr.__class__.__name__ == 'RelationshipProperty':
+        attrs = []
+        for ar, ar_value in attr.mapper.attrs.items():
+            if ar_value.__class__.__name__ == 'ColumnProperty' and ar not in attrs:
+                attrs.append(ar)
+        if attr_value.__class__.__name__ == 'InstrumentedList':
+            new_data = []
+            for item in attr_value:
+                info = dict()
+                for ar in attrs:
+                    new_attr_value = getattr(item, ar)
+                    if not item.__class__.__name__ == 'RelationshipProperty':
+                        info[ar] = new_attr_value
+                    else:
+                        info = covert_relationship_property(ar, new_attr_value)
+                new_data.append(info)
+            return new_data
+        else:
+            new_data = dict()
+            for column, value in attr.entity.attrs.items():
+                if not value.__class__.__name__ == 'RelationshipProperty':
+                    new_data[column] = getattr(attr_value, column)
+            return new_data
+    else:
+        return attr_value
+
+
 def query_set_to_dict(obj):
-    if hasattr(obj, "__table__"):
+    if hasattr(obj, "__mapper__"):
         obj_dict = {}
-        for column in obj.__table__.columns.keys():
-            if hasattr(obj, column):
-                val = getattr(obj, column)
-                if isinstance(val, Decimal):
-                    val = float(val)
-                obj_dict[column] = val
+        mapper = obj.__mapper__
+        if hasattr(mapper, "attrs"):
+            attrs = mapper.attrs
+            for column, attr in attrs.items():
+                attr_value = getattr(obj, column)
+                value = covert_relationship_property(attr, attr_value)
+                if not value.__class__.__name__ == 'RelationshipProperty':
+                    obj_dict[column] = value
+
         return obj_dict
     elif hasattr(obj, "keys"):
         return {key: getattr(obj, key) for key in obj.keys()}
