@@ -6,8 +6,16 @@ def format_param_tag(bool_should_more_list, especial_tag_list):
     if especial_tag_list is not None:
         for tag in especial_tag_list:
 
-            # diy_tag
-            if tag in ["国家级专精特新", "省级专精特新", "国家级单项冠军", "瞪羚"]:
+            if tag == "省级专精特新":
+                bool_should_list.append(
+                    {"bool":
+                        {"must": [
+                            {"terms": {"tags.diy_tag": ["省级专精特新企业"]}},
+                            {"bool": {"must_not": [{"terms": {"tags.diy_tag": ["国家级专精特新企业"]}}]}}
+                        ]
+                        }
+                    })
+            if tag in ["国家级专精特新", "国家级单项冠军", "瞪羚"]:
                 es_condition_by_terms(bool_should_list, "tags.diy_tag", [tag + "企业"])
             if tag in ["高新技术企业", "央企", "瞪羚企业", "中国企业500强"]:
                 es_condition_by_terms(bool_should_list, "tags.diy_tag", [tag])
